All of lore.kernel.org
 help / color / mirror / Atom feed
From: Pavan Bobba <opensource206@gmail.com>
To: Greg Kroah-Hartman <gregkh@linuxfoundation.org>,
	linux-staging@lists.linux.dev, linux-kernel@vger.kernel.org
Cc: Pavan Bobba <opensource206@gmail.com>
Subject: [PATCH 07/11] staging: vt6655: Type encoding info dropped from function name "CARDqGetNextTBTT"
Date: Tue, 31 Oct 2023 11:04:30 +0530	[thread overview]
Message-ID: <8e142b33245e6933fb178080b0b14371939a84e6.1698730318.git.opensource206@gmail.com> (raw)
In-Reply-To: <cover.1698730318.git.opensource206@gmail.com>

function name "CARDqGetNextTBTT" updated like below:

a.type encoding info dropped from name
b.camelcase name replaced by snakecase

Issue found by checkpatch

Signed-off-by: Pavan Bobba <opensource206@gmail.com>
---
 drivers/staging/vt6655/card.c | 10 +++++-----
 drivers/staging/vt6655/card.h |  2 +-
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/drivers/staging/vt6655/card.h b/drivers/staging/vt6655/card.h
index 1758a95f3ab0..ab1193799239 100644
--- a/drivers/staging/vt6655/card.h
+++ b/drivers/staging/vt6655/card.h
@@ -47,7 +47,7 @@ void CARDvSetFirstNextTBTT(struct vnt_private *priv,
 void CARDvUpdateNextTBTT(struct vnt_private *priv, u64 qwTSF,
 			 unsigned short beacon_interval);
 u64 vt6655_get_current_tsf(struct vnt_private *priv);
-u64 CARDqGetNextTBTT(u64 qwTSF, unsigned short beacon_interval);
+u64 card_get_next_tbtt(u64 qwTSF, unsigned short beacon_interval);
 u64 card_get_tsf_offset(unsigned char rx_rate, u64 qwTSF1, u64 qwTSF2);
 unsigned char card_get_pkt_type(struct vnt_private *priv);
 void CARDvSafeResetTx(struct vnt_private *priv);
diff --git a/drivers/staging/vt6655/card.c b/drivers/staging/vt6655/card.c
index e4b40125b094..716fd3632508 100644
--- a/drivers/staging/vt6655/card.c
+++ b/drivers/staging/vt6655/card.c
@@ -12,7 +12,7 @@
  *      CARDbIsOFDMinBasicRate - Check if any OFDM rate is in BasicRateSet
  *      card_get_tsf_offset - Calculate TSFOffset
  *      vt6655_get_current_tsf - Read Current NIC TSF counter
  *      CARDqGetNextTBTT - Calculate Next Beacon TSF counter
  *      CARDvSetFirstNextTBTT - Set NIC Beacon time
  *      CARDvUpdateNextTBTT - Sync. NIC Beacon time
  *      CARDbRadioPowerOff - Turn Off NIC Radio Power
@@ -327,7 +327,7 @@ bool card_set_beacon_period(struct vnt_private *priv,
 
 	next_tbtt = vt6655_get_current_tsf(priv); /* Get Local TSF counter */
 
-	next_tbtt = CARDqGetNextTBTT(next_tbtt, beacon_interval);
+	next_tbtt = card_get_next_tbtt(next_tbtt, beacon_interval);
 
 	/* set HW beacon interval */
 	iowrite16(beacon_interval, priv->port_offset + MAC_REG_BI);
@@ -764,7 +764,7 @@ u64 vt6655_get_current_tsf(struct vnt_private *priv)
  *
  * Return Value: TSF value of next Beacon
  */
-u64 CARDqGetNextTBTT(u64 qwTSF, unsigned short beacon_interval)
+u64 card_get_next_tbtt(u64 qwTSF, unsigned short beacon_interval)
 {
 	u32 beacon_int;
 
@@ -799,7 +799,7 @@ void CARDvSetFirstNextTBTT(struct vnt_private *priv,
 
 	next_tbtt = vt6655_get_current_tsf(priv); /* Get Local TSF counter */
 
-	next_tbtt = CARDqGetNextTBTT(next_tbtt, beacon_interval);
+	next_tbtt = card_get_next_tbtt(next_tbtt, beacon_interval);
 	/* Set NextTBTT */
 	next_tbtt =  le64_to_cpu(next_tbtt);
 	iowrite32((u32)next_tbtt, iobase + MAC_REG_NEXTTBTT);
@@ -826,7 +826,7 @@ void CARDvUpdateNextTBTT(struct vnt_private *priv, u64 qwTSF,
 {
 	void __iomem *iobase = priv->port_offset;
 
-	qwTSF = CARDqGetNextTBTT(qwTSF, beacon_interval);
+	qwTSF = card_get_next_tbtt(qwTSF, beacon_interval);
 	/* Set NextTBTT */
 	qwTSF =  le64_to_cpu(qwTSF);
 	iowrite32((u32)qwTSF, iobase + MAC_REG_NEXTTBTT);
@@ -12,7 +12,7 @@
  *      card_get_tsf_offset - Calculate TSFOffset
  *      vt6655_get_current_tsf - Read Current NIC TSF counter
- *      CARDqGetNextTBTT - Calculate Next Beacon TSF counter
+ *      card_get_next_tbtt - Calculate Next Beacon TSF counter
  *      CARDvSetFirstNextTBTT - Set NIC Beacon time
  *      CARDvUpdateNextTBTT - Sync. NIC Beacon time
-- 
2.34.1


  parent reply	other threads:[~2023-10-31  5:34 UTC|newest]

Thread overview: 13+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2023-10-31  5:34 [PATCH 00/11] Type encoding info dropped from variable and function names in NIC driver part2 Pavan Bobba
2023-10-31  5:34 ` [PATCH 01/11] staging: vt6655: Type encoding info dropped from variable name "qwBSSTimestamp" Pavan Bobba
2023-10-31  5:34 ` [PATCH 02/11] staging: vt6655: Type encoding info dropped from variable name "qwTSFOffset" Pavan Bobba
2023-10-31  5:34 ` [PATCH 03/11] staging: vt6655: Type encoding info dropped from function name "CARDqGetTSFOffset" Pavan Bobba
2023-10-31  5:34 ` [PATCH 04/11] staging: vt6655: Type encoding info dropped from function name "CARDbSetBeaconPeriod" Pavan Bobba
2023-10-31  5:34 ` [PATCH 05/11] staging: vt6655: Type encoding info dropped from variable name "wBeaconInterval" Pavan Bobba
2023-10-31  5:34 ` [PATCH 06/11] staging: vt6655: Type encoding info dropped from variable name "qwNextTBTT" Pavan Bobba
2023-10-31  5:34 ` Pavan Bobba [this message]
2023-10-31  5:34 ` [PATCH 08/11] staging: vt6655: Type encoding info dropped from function name "CARDbRadioPowerOff" Pavan Bobba
2023-10-31  5:34 ` [PATCH 09/11] staging: vt6655: Type encoding info dropped from function name "CARDvSafeResetTx" Pavan Bobba
2023-10-31  5:34 ` [PATCH 10/11] staging: vt6655: Type encoding info dropped from variable name "pCurrTD" Pavan Bobba
2023-10-31  5:34 ` [PATCH 11/11] staging: vt6655: Type encoding info dropped from variable name "apTailTD" Pavan Bobba
2023-11-04 11:39 ` [PATCH 00/11] Type encoding info dropped from variable and function names in NIC driver part2 Philipp Hortmann

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=8e142b33245e6933fb178080b0b14371939a84e6.1698730318.git.opensource206@gmail.com \
    --to=opensource206@gmail.com \
    --cc=gregkh@linuxfoundation.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-staging@lists.linux.dev \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.